@@ -52,7 +52,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 		if verify {
 			timeout := 10 * time.Second
 			client.Timeout = timeout
-			req, err := http.NewRequest("POST", "https://convier.me/api/event", nil)
+			req, err := http.NewRequestWithContext(ctx, "POST", "https://convier.me/api/event", nil)
 			if err != nil {
 				continue
 			}
